@@ -2,7 +2,7 @@
 -- mysql.sql
 -- DB definition for MySQL
 --
--- Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
+-- Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
 --
 -- -- --------------------------------------------------------
 
@@ -83,7 +83,7 @@ CREATE TABLE IF NOT EXISTS icinga_commenthistory (
   deletion_time timestamp  default '0000-00-00 00:00:00',
   deletion_time_usec  int default 0,
   PRIMARY KEY  (commenthistory_id),
-  UNIQUE KEY instance_id (instance_id,comment_time,internal_comment_id)
+  UNIQUE KEY instance_id (instance_id,object_id,comment_time,internal_comment_id)
 ) ENGINE=InnoDB  COMMENT='Historical host and service comments';
 
 -- --------------------------------------------------------
@@ -109,7 +109,7 @@ CREATE TABLE IF NOT EXISTS icinga_comments (
   expires smallint default 0,
   expiration_time timestamp  default '0000-00-00 00:00:00',
   PRIMARY KEY  (comment_id),
-  UNIQUE KEY instance_id (instance_id,comment_time,internal_comment_id)
+  UNIQUE KEY instance_id (instance_id,object_id,comment_time,internal_comment_id)
 ) ENGINE=InnoDB  COMMENT='Usercomments on Icinga objects';
 
 -- --------------------------------------------------------
@@ -152,10 +152,10 @@ CREATE TABLE IF NOT EXISTS icinga_conninfo (
   conninfo_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
   instance_id bigint unsigned default 0,
   agent_name varchar(32) character set latin1  default '',
-  agent_version varchar(16) character set latin1  default '',
-  disposition varchar(16) character set latin1  default '',
-  connect_source varchar(16) character set latin1  default '',
-  connect_type varchar(16) character set latin1  default '',
+  agent_version varchar(32) character set latin1  default '',
+  disposition varchar(32) character set latin1  default '',
+  connect_source varchar(32) character set latin1  default '',
+  connect_type varchar(32) character set latin1  default '',
   connect_time timestamp  default '0000-00-00 00:00:00',
   disconnect_time timestamp  default '0000-00-00 00:00:00',
   last_checkin_time timestamp  default '0000-00-00 00:00:00',
@@ -247,7 +247,7 @@ CREATE TABLE IF NOT EXISTS icinga_contacts (
   instance_id bigint unsigned default 0,
   config_type smallint default 0,
   contact_object_id bigint unsigned default 0,
-  alias varchar(64) character set latin1  default '',
+  alias TEXT character set latin1  default '',
   email_address varchar(255) character set latin1  default '',
   pager_address varchar(64) character set latin1  default '',
   host_timeperiod_object_id bigint unsigned default 0,
@@ -337,8 +337,9 @@ CREATE TABLE IF NOT EXISTS icinga_customvariables (
   object_id bigint unsigned default 0,
   config_type smallint default 0,
   has_been_modified smallint default 0,
-  varname varchar(255) character set latin1  default '',
+  varname varchar(255) character set latin1 collate latin1_general_cs default NULL,
   varvalue TEXT character set latin1  default '',
+  is_json smallint default 0,
   PRIMARY KEY  (customvariable_id),
   UNIQUE KEY object_id_2 (object_id,config_type,varname),
   KEY varname (varname)
@@ -356,8 +357,9 @@ CREATE TABLE IF NOT EXISTS icinga_customvariablestatus (
   object_id bigint unsigned default 0,
   status_update_time timestamp  default '0000-00-00 00:00:00',
   has_been_modified smallint default 0,
-  varname varchar(255) character set latin1  default '',
+  varname varchar(255) character set latin1 collate latin1_general_cs default NULL,
   varvalue TEXT character set latin1  default '',
+  is_json smallint default 0,
   PRIMARY KEY  (customvariablestatus_id),
   UNIQUE KEY object_id_2 (object_id,varname),
   KEY varname (varname)
@@ -396,7 +398,7 @@ CREATE TABLE IF NOT EXISTS icinga_downtimehistory (
   internal_downtime_id bigint unsigned default 0,
   triggered_by_id bigint unsigned default 0,
   is_fixed smallint default 0,
-  duration smallint default 0,
+  duration bigint(20) default 0,
   scheduled_start_time timestamp  default '0000-00-00 00:00:00',
   scheduled_end_time timestamp  default '0000-00-00 00:00:00',
   was_started smallint default 0,
@@ -600,6 +602,9 @@ CREATE TABLE IF NOT EXISTS icinga_hostgroups (
   config_type smallint default 0,
   hostgroup_object_id bigint unsigned default 0,
   alias TEXT character set latin1  default '',
+  notes TEXT character set latin1  default NULL,
+  notes_url TEXT character set latin1  default NULL,
+  action_url TEXT character set latin1  default NULL,
   PRIMARY KEY  (hostgroup_id),
   UNIQUE KEY instance_id (instance_id,hostgroup_object_id)
 ) ENGINE=InnoDB  COMMENT='Hostgroup definitions';
@@ -629,7 +634,7 @@ CREATE TABLE IF NOT EXISTS icinga_hosts (
   instance_id bigint unsigned default 0,
   config_type smallint default 0,
   host_object_id bigint unsigned default 0,
-  alias varchar(64) character set latin1  default '',
+  alias TEXT character set latin1  default '',
   display_name varchar(255) character set latin1 collate latin1_general_cs  default '',
   address varchar(128) character set latin1  default '',
   address6 varchar(128) character set latin1  default '',
@@ -703,6 +708,7 @@ CREATE TABLE IF NOT EXISTS icinga_hoststatus (
   output TEXT character set latin1  default '',
   long_output TEXT  default '',
   perfdata TEXT character set latin1  default '',
+  check_source TEXT character set latin1  default '',
   current_state smallint default 0,
   has_been_checked smallint default 0,
   should_be_scheduled smallint default 0,
@@ -743,6 +749,7 @@ CREATE TABLE IF NOT EXISTS icinga_hoststatus (
   normal_check_interval double  default '0',
   retry_check_interval double  default '0',
   check_timeperiod_object_id bigint unsigned default 0,
+  is_reachable smallint default 0,
   PRIMARY KEY  (hoststatus_id),
   UNIQUE KEY object_id (host_object_id)
 ) ENGINE=InnoDB  COMMENT='Current host status information';
@@ -818,6 +825,7 @@ CREATE TABLE IF NOT EXISTS icinga_logentries (
   logentry_data TEXT character set latin1  default '',
   realtime_data smallint default 0,
   inferred_data_extracted smallint default 0,
+  object_id bigint unsigned default NULL,
   PRIMARY KEY  (logentry_id)
 ) ENGINE=InnoDB COMMENT='Historical record of log entries';
 
@@ -891,9 +899,11 @@ CREATE TABLE IF NOT EXISTS icinga_processevents (
 CREATE TABLE IF NOT EXISTS icinga_programstatus (
   programstatus_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
   instance_id bigint unsigned default 0,
+  program_version varchar(64) character set latin1 collate latin1_general_cs default NULL,
   status_update_time timestamp  default '0000-00-00 00:00:00',
   program_start_time timestamp  default '0000-00-00 00:00:00',
   program_end_time timestamp  default '0000-00-00 00:00:00',
+  endpoint_name varchar(255) character set latin1 collate latin1_general_cs default NULL,
   is_currently_running smallint default 0,
   process_id bigint unsigned default 0,
   daemon_mode smallint default 0,
@@ -915,6 +925,7 @@ CREATE TABLE IF NOT EXISTS icinga_programstatus (
   modified_service_attributes  int default 0,
   global_host_event_handler TEXT character set latin1  default '',
   global_service_event_handler TEXT character set latin1  default '',
+  config_dump_in_progress smallint default 0,
   PRIMARY KEY  (programstatus_id),
   UNIQUE KEY instance_id (instance_id)
 ) ENGINE=InnoDB  COMMENT='Current program status information';
@@ -950,7 +961,7 @@ CREATE TABLE IF NOT EXISTS icinga_scheduleddowntime (
   internal_downtime_id bigint unsigned default 0,
   triggered_by_id bigint unsigned default 0,
   is_fixed smallint default 0,
-  duration smallint default 0,
+  duration bigint(20) default 0,
   scheduled_start_time timestamp  default '0000-00-00 00:00:00',
   scheduled_end_time timestamp  default '0000-00-00 00:00:00',
   was_started smallint default 0,
@@ -1083,6 +1094,9 @@ CREATE TABLE IF NOT EXISTS icinga_servicegroups (
   config_type smallint default 0,
   servicegroup_object_id bigint unsigned default 0,
   alias TEXT character set latin1  default '',
+  notes TEXT character set latin1  default NULL,
+  notes_url TEXT character set latin1  default NULL,
+  action_url TEXT character set latin1  default NULL,
   PRIMARY KEY  (servicegroup_id),
   UNIQUE KEY instance_id (instance_id,config_type,servicegroup_object_id)
 ) ENGINE=InnoDB  COMMENT='Servicegroup definitions';
@@ -1179,6 +1193,7 @@ CREATE TABLE IF NOT EXISTS icinga_servicestatus (
   output TEXT character set latin1  default '',
   long_output TEXT  default '',
   perfdata TEXT character set latin1  default '',
+  check_source TEXT character set latin1  default '',
   current_state smallint default 0,
   has_been_checked smallint default 0,
   should_be_scheduled smallint default 0,
@@ -1220,6 +1235,7 @@ CREATE TABLE IF NOT EXISTS icinga_servicestatus (
   normal_check_interval double  default '0',
   retry_check_interval double  default '0',
   check_timeperiod_object_id bigint unsigned default 0,
+  is_reachable smallint default 0,
   PRIMARY KEY  (servicestatus_id),
   UNIQUE KEY object_id (service_object_id)
 ) ENGINE=InnoDB  COMMENT='Current service status information';
@@ -1273,6 +1289,7 @@ CREATE TABLE IF NOT EXISTS icinga_statehistory (
   last_hard_state smallint default 0,
   output TEXT character set latin1  default '',
   long_output TEXT  default '',
+  check_source varchar(255) character set latin1 default NULL,
   PRIMARY KEY  (statehistory_id)
 ) ENGINE=InnoDB COMMENT='Historical host and service state changes';
 
@@ -1302,48 +1319,6 @@ CREATE TABLE IF NOT EXISTS icinga_systemcommands (
 
 -- --------------------------------------------------------
 
---
--- Table structure for table icinga_timedeventqueue
---
-
-CREATE TABLE IF NOT EXISTS icinga_timedeventqueue (
-  timedeventqueue_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
-  instance_id bigint unsigned default 0,
-  event_type smallint default 0,
-  queued_time timestamp  default '0000-00-00 00:00:00',
-  queued_time_usec  int default 0,
-  scheduled_time timestamp  default '0000-00-00 00:00:00',
-  recurring_event smallint default 0,
-  object_id bigint unsigned default 0,
-  PRIMARY KEY  (timedeventqueue_id),
-  UNIQUE KEY instance_id (instance_id,event_type,scheduled_time,object_id)
-) ENGINE=InnoDB  COMMENT='Current Icinga event queue';
-
--- --------------------------------------------------------
-
---
--- Table structure for table icinga_timedevents
---
-
-CREATE TABLE IF NOT EXISTS icinga_timedevents (
-  timedevent_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
-  instance_id bigint unsigned default 0,
-  event_type smallint default 0,
-  queued_time timestamp  default '0000-00-00 00:00:00',
-  queued_time_usec  int default 0,
-  event_time timestamp  default '0000-00-00 00:00:00',
-  event_time_usec  int default 0,
-  scheduled_time timestamp  default '0000-00-00 00:00:00',
-  recurring_event smallint default 0,
-  object_id bigint unsigned default 0,
-  deletion_time timestamp  default '0000-00-00 00:00:00',
-  deletion_time_usec  int default 0,
-  PRIMARY KEY  (timedevent_id),
-  UNIQUE KEY instance_id (instance_id,event_type,scheduled_time,object_id)
-) ENGINE=InnoDB  COMMENT='Historical events from the Icinga event queue';
-
--- --------------------------------------------------------
-
 --
 -- Table structure for table icinga_timeperiods
 --
@@ -1374,25 +1349,66 @@ CREATE TABLE IF NOT EXISTS icinga_timeperiod_timeranges (
   PRIMARY KEY  (timeperiod_timerange_id)
 ) ENGINE=InnoDB  COMMENT='Timeperiod definitions';
 
+
+-- --------------------------------------------------------
+-- Icinga 2 specific schema extensions
 -- --------------------------------------------------------
 
 --
--- Table structure for table icinga_slahistory
+-- Table structure for table icinga_endpoints
 --
 
-CREATE TABLE IF NOT EXISTS icinga_slahistory (
-  slahistory_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
+CREATE TABLE IF NOT EXISTS icinga_endpoints (
+  endpoint_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
   instance_id bigint unsigned default 0,
-  start_time timestamp null default NULL,
-  end_time timestamp null default NULL,
-  acknowledgement_time timestamp null default NULL,
-  object_id bigint unsigned default 0,
-  state smallint default 0,
-  state_type smallint default '0',
-  scheduled_downtime tinyint(1) default 0,
-  PRIMARY KEY (slahistory_id)
-) ENGINE=InnoDB COMMENT='SLA statehistory';
+  endpoint_object_id bigint(20) unsigned DEFAULT '0',
+  config_type smallint(6) DEFAULT '0',
+  identity varchar(255) DEFAULT NULL,
+  node varchar(255) DEFAULT NULL,
+  PRIMARY KEY  (endpoint_id)
+) ENGINE=InnoDB COMMENT='Endpoint configuration';
 
+-- --------------------------------------------------------
+
+--
+-- Table structure for table icinga_endpointstatus
+--
+
+CREATE TABLE IF NOT EXISTS icinga_endpointstatus (
+  endpointstatus_id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
+  instance_id bigint unsigned default 0,
+  endpoint_object_id bigint(20) unsigned DEFAULT '0',
+  status_update_time timestamp NOT NULL DEFAULT '0000-00-00 00:00:00',
+  identity varchar(255) DEFAULT NULL,
+  node varchar(255) DEFAULT NULL,
+  is_connected smallint(6),
+  PRIMARY KEY  (endpointstatus_id)
+) ENGINE=InnoDB COMMENT='Endpoint status';
+
+
+ALTER TABLE icinga_servicestatus ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_hoststatus ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_contactstatus ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_programstatus ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_comments ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_scheduleddowntime ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_runtimevariables ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_customvariablestatus ADD COLUMN endpoint_object_id bigint default NULL;
+
+ALTER TABLE icinga_acknowledgements ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_commenthistory ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_contactnotifications ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_downtimehistory ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_eventhandlers ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_externalcommands ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_flappinghistory ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_hostchecks ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_logentries ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_notifications ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_processevents ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_servicechecks ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_statehistory ADD COLUMN endpoint_object_id bigint default NULL;
+ALTER TABLE icinga_systemcommands ADD COLUMN endpoint_object_id bigint default NULL;
 
 -- -----------------------------------------
 -- add index (delete)
@@ -1400,13 +1416,10 @@ CREATE TABLE IF NOT EXISTS icinga_slahistory (
 
 -- for periodic delete 
 -- instance_id and
--- TIMEDEVENTS => scheduled_time
 -- SYSTEMCOMMANDS, SERVICECHECKS, HOSTCHECKS, EVENTHANDLERS  => start_time
 -- EXTERNALCOMMANDS => entry_time
 
 -- instance_id
-CREATE INDEX timedevents_i_id_idx on icinga_timedevents(instance_id);
-CREATE INDEX timedeventq_i_id_idx on icinga_timedeventqueue(instance_id);
 CREATE INDEX systemcommands_i_id_idx on icinga_systemcommands(instance_id);
 CREATE INDEX servicechecks_i_id_idx on icinga_servicechecks(instance_id);
 CREATE INDEX hostchecks_i_id_idx on icinga_hostchecks(instance_id);
@@ -1414,8 +1427,6 @@ CREATE INDEX eventhandlers_i_id_idx on icinga_eventhandlers(instance_id);
 CREATE INDEX externalcommands_i_id_idx on icinga_externalcommands(instance_id);
 
 -- time
-CREATE INDEX timedevents_time_id_idx on icinga_timedevents(scheduled_time);
-CREATE INDEX timedeventq_time_id_idx on icinga_timedeventqueue(scheduled_time);
 CREATE INDEX systemcommands_time_id_idx on icinga_systemcommands(start_time);
 CREATE INDEX servicechecks_time_id_idx on icinga_servicechecks(start_time);
 CREATE INDEX hostchecks_time_id_idx on icinga_hostchecks(start_time);
@@ -1431,7 +1442,6 @@ CREATE INDEX programstatus_i_id_idx on icinga_programstatus(instance_id);
 CREATE INDEX hoststatus_i_id_idx on icinga_hoststatus(instance_id);
 CREATE INDEX servicestatus_i_id_idx on icinga_servicestatus(instance_id);
 CREATE INDEX contactstatus_i_id_idx on icinga_contactstatus(instance_id);
-CREATE INDEX timedeventqueue_i_id_idx on icinga_timedeventqueue(instance_id);
 CREATE INDEX comments_i_id_idx on icinga_comments(instance_id);
 CREATE INDEX scheduleddowntime_i_id_idx on icinga_scheduleddowntime(instance_id);
 CREATE INDEX runtimevariables_i_id_idx on icinga_runtimevariables(instance_id);
@@ -1514,18 +1524,6 @@ CREATE INDEX srvcstatus_latency_idx on icinga_servicestatus(latency);
 CREATE INDEX srvcstatus_ex_time_idx on icinga_servicestatus(execution_time);
 CREATE INDEX srvcstatus_sch_downt_d_idx on icinga_servicestatus(scheduled_downtime_depth);
 
--- timedeventqueue
-CREATE INDEX timed_e_q_event_type_idx on icinga_timedeventqueue(event_type);
-CREATE INDEX timed_e_q_sched_time_idx on icinga_timedeventqueue(scheduled_time);
-CREATE INDEX timed_e_q_object_id_idx on icinga_timedeventqueue(object_id);
-CREATE INDEX timed_e_q_rec_ev_id_idx on icinga_timedeventqueue(recurring_event);
-
--- timedevents
-CREATE INDEX timed_e_event_type_idx on icinga_timedevents(event_type);
--- CREATE INDEX timed_e_sched_time_idx on icinga_timedevents(scheduled_time); --already set for delete
-CREATE INDEX timed_e_object_id_idx on icinga_timedevents(object_id);
-CREATE INDEX timed_e_rec_ev_idx on icinga_timedevents(recurring_event);
-
 -- hostchecks
 CREATE INDEX hostchks_h_obj_id_idx on icinga_hostchecks(host_object_id);
 
@@ -1574,9 +1572,6 @@ CREATE INDEX statehist_i_id_o_id_s_ty_s_ti on icinga_statehistory(instance_id, o
 create index statehist_state_idx on icinga_statehistory(object_id,state);
 
 
--- SLA statehistory
-CREATE INDEX slahist_i_id_o_id_s_ti_s_s_ti_e on icinga_slahistory(instance_id,object_id,start_time,end_time);
-
 -- Icinga Web Notifications
 CREATE INDEX notification_idx ON icinga_notifications(notification_type, object_id, start_time);
 CREATE INDEX notification_object_id_idx ON icinga_notifications(object_id);
@@ -1597,9 +1592,17 @@ CREATE INDEX sgmbrs_sgid_soid ON icinga_servicegroup_members (servicegroup_id,se
 CREATE INDEX scgrps_sid_cgoid ON icinga_service_contactgroups (service_id,contactgroup_object_id);
 CREATE INDEX tperiod_tid_d_ss_es ON icinga_timeperiod_timeranges (timeperiod_id,day,start_sec,end_sec);
 
+-- #3649
+CREATE INDEX sla_idx_sthist ON icinga_statehistory (object_id, state_time DESC);
+CREATE INDEX sla_idx_dohist ON icinga_downtimehistory (object_id, actual_start_time, actual_end_time);
+CREATE INDEX sla_idx_obj ON icinga_objects (objecttype_id, is_active, name1);
+
+-- #4985
+CREATE INDEX commenthistory_delete_idx ON icinga_commenthistory (instance_id, comment_time, internal_comment_id);
+
 -- -----------------------------------------
 -- set dbversion
 -- -----------------------------------------
-INSERT INTO icinga_dbversion (name, version, create_time, modify_time) VALUES ('idoutils', '1.8.0', NOW(), NOW()) ON DUPLICATE KEY UPDATE version='1.8.0', modify_time=NOW();
+INSERT INTO icinga_dbversion (name, version, create_time, modify_time) VALUES ('idoutils', '1.12.0', NOW(), NOW()) ON DUPLICATE KEY UPDATE version='1.12.0', modify_time=NOW();
 
 
