@@ -4,11 +4,8 @@
 -- icinga DB object definition for Oracle
 -- called and defines set from oracle.sql
 --
--- Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
+-- Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
 --
--- initial version: 2008-02-20 David Schmidt
---                  2011-01-17 Michael Friedrich <michael.friedrich(at)univie.ac.at>
--- current version: 2012-01-29 Thomas Dressler
 -- -- --------------------------------------------------------
 */
 -- -----------------------------------------
@@ -302,7 +299,7 @@ CREATE TABLE commenthistory (
 
 alter table commenthistory add constraint commenthist_pk PRIMARY KEY  (id)
 	using index tablespace &&IDXTBS;
-alter table commenthistory add constraint commenthist_uq  UNIQUE (instance_id,comment_time,internal_comment_id)
+alter table commenthistory add constraint commenthist_uq  UNIQUE (instance_id,object_id,comment_time,internal_comment_id)
 	using index tablespace &&IDXTBS;
 -- --------------------------------------------------------
 
@@ -330,7 +327,7 @@ CREATE TABLE comments (
 
 alter table comments add constraint comments_pk PRIMARY KEY  (id)
 	using index tablespace &&IDXTBS;
-alter table comments add constraint comments_uq  UNIQUE (instance_id,comment_time,internal_comment_id)
+alter table comments add constraint comments_uq  UNIQUE (instance_id,object_id,comment_time,internal_comment_id)
 	using index tablespace &&IDXTBS;
 	
 
@@ -379,10 +376,10 @@ CREATE TABLE conninfo (
   id integer ,
   instance_id integer default 0 ,
   agent_name varchar2(32),
-  agent_version varchar2(16),
-  disposition varchar2(16),
-  connect_source varchar2(16),
-  connect_type varchar2(16),
+  agent_version varchar2(32),
+  disposition varchar2(32),
+  connect_source varchar2(32),
+  connect_type varchar2(32),
   connect_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   disconnect_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   last_checkin_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
@@ -528,7 +525,7 @@ CREATE TABLE contacts (
   instance_id integer default 0 ,
   config_type integer default 0 ,
   contact_object_id integer default 0 ,
-  alias varchar2(64),
+  alias varchar2(1024),
   email_address varchar2(1024),
   pager_address varchar2(64),
   host_timeperiod_object_id integer default 0 ,
@@ -708,10 +705,11 @@ CREATE TABLE eventhandlers (
   early_timeout integer default 0 ,
   execution_time number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob
 )
-lob (long_output) store as eventhandlers_out_lob(tablespace &&LOBTBS)
+lob (output) store as eventhandlers_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as eventhandlers_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
 alter table eventhandlers add constraint eventhandlers_pk PRIMARY KEY  (id)
@@ -844,10 +842,11 @@ CREATE TABLE hostchecks (
   execution_time number default 0 ,
   latency number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob)
-  lob (long_output) store as hostchecks_out_lob(tablespace &&LOBTBS)
+  lob (output) store as hostchecks_outp_lob(tablespace &&LOBTBS)
+  lob (long_output) store as hostchecks_loutp_lob(tablespace &&LOBTBS)
   lob (perfdata) store as hostchecks_perf_lob(tablespace &&LOBTBS)
   tablespace &&DATATBS;
 
@@ -1066,9 +1065,10 @@ CREATE TABLE hoststatus (
   instance_id integer default 0 ,
   host_object_id integer default 0 ,
   status_update_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob,
+  check_source varchar2(255) default '',
   current_state integer default 0 ,
   has_been_checked integer default 0 ,
   should_be_scheduled integer default 0 ,
@@ -1110,7 +1110,8 @@ CREATE TABLE hoststatus (
   retry_check_interval number default 0 ,
   check_timeperiod_object_id integer default 0 
 )
-lob (long_output) store as hoststatus_out_lob(tablespace &&LOBTBS)
+lob (output) store as hoststatus_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as hoststatus_loutp_lob(tablespace &&LOBTBS)
 lob (perfdata) store as hoststatus_perf_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
@@ -1152,7 +1153,8 @@ CREATE TABLE logentries (
   logentry_type integer default 0 ,
   logentry_data clob,
   realtime_data integer default 0 ,
-  inferred_data_extracted integer default 0 
+  inferred_data_extracted integer default 0 ,
+  object_id integer default NULL
 )
 lob (logentry_data) store as logentries_data_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
@@ -1178,12 +1180,13 @@ CREATE TABLE notifications (
   end_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   end_time_usec integer default 0 ,
   state integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   escalated integer default 0 ,
   contacts_notified integer default 0 
 )
-lob (long_output) store as notific_out_lob(tablespace &&LOBTBS)
+lob (output) store as notifications_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as notifications_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
 alter table notifications add constraint notifications_pk PRIMARY KEY  (id)
@@ -1247,6 +1250,7 @@ alter table processevents add constraint processevents_pk PRIMARY KEY  (id)
 CREATE TABLE programstatus (
   id integer ,
   instance_id integer default 0 ,
+  program_version varchar2(64),
   status_update_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   program_start_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   program_end_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
@@ -1270,7 +1274,8 @@ CREATE TABLE programstatus (
   modified_host_attributes integer default 0 ,
   modified_service_attributes integer default 0 ,
   global_host_event_handler varchar2(1024),
-  global_service_event_handler varchar2(1024)
+  global_service_event_handler varchar2(1024),
+  config_dump_in_progress integer default 0
 )tablespace &&DATATBS;
 
 alter table programstatus add constraint programstatus_pk PRIMARY KEY  (id)
@@ -1391,11 +1396,12 @@ CREATE TABLE servicechecks (
   execution_time number default 0 ,
   latency number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob
 )
-lob (long_output) store as servicechecks_out_lob(tablespace &&LOBTBS)
+lob (output) store as servicechecks_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as servicechecks_loutp_lob(tablespace &&LOBTBS)
 lob (perfdata) store as servicechecks_perf_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
@@ -1606,9 +1612,10 @@ CREATE TABLE servicestatus (
   instance_id integer default 0 ,
   service_object_id integer default 0 ,
   status_update_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob,
+  check_source varchar2(255) default '',
   current_state integer default 0 ,
   has_been_checked integer default 0 ,
   should_be_scheduled integer default 0 ,
@@ -1651,7 +1658,8 @@ CREATE TABLE servicestatus (
   retry_check_interval number default 0 ,
   check_timeperiod_object_id integer default 0 
 )
-lob (long_output) store as servicestatus_out_lob(tablespace &&LOBTBS)
+lob (output) store as servicestatus_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as servicestatus_loutp_lob(tablespace &&LOBTBS)
 lob (perfdata) store as servicestatus_perf_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
@@ -1680,10 +1688,12 @@ CREATE TABLE statehistory (
   max_check_attempts integer default 0 ,
   last_state integer default -1 ,
   last_hard_state integer default -1 ,
-  output varchar2(2048),
-  long_output clob
+  output clob,
+  long_output clob,
+  check_source varchar2(255)
 )
-lob (long_output) store as statehistory_out_lob(tablespace &&LOBTBS)
+lob (output) store as statehistory_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as statehistory_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 alter table statehistory add constraint statehistory_pk PRIMARY KEY  (id)
 	using index tablespace &&IDXTBS;
@@ -1708,10 +1718,11 @@ CREATE TABLE systemcommands (
   early_timeout integer default 0 ,
   execution_time number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob
 )
-lob (long_output) store as systemcommands_out_lob(tablespace &&LOBTBS)
+lob (output) store as systemcommands_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as systemcommands_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
 alter table systemcommands add constraint systemcommands_pk PRIMARY KEY  (id)
@@ -1720,53 +1731,6 @@ alter table systemcommands add CONSTRAINT systemcommands_uq UNIQUE (instance_id,
 	using index tablespace &&IDXTBS;
 
 
--- --------------------------------------------------------
-
--- 
--- Table structure for table timedeventqueue
--- 
-
-CREATE TABLE timedeventqueue (
-  id integer ,
-  instance_id integer default 0 ,
-  event_type integer default 0 ,
-  queued_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  queued_time_usec integer default 0 ,
-  scheduled_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  recurring_event integer default 0 ,
-  object_id integer default 0 
-)tablespace &&DATATBS;
-alter table timedeventqueue add constraint timedeventqueue_pk PRIMARY KEY  (id)
-	using index tablespace &&IDXTBS;
-
-
-
--- --------------------------------------------------------
-
--- 
--- Table structure for table timedevents
--- 
-
-CREATE TABLE timedevents (
-  id integer ,
-  instance_id integer default 0 ,
-  event_type integer default 0 ,
-  queued_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  queued_time_usec integer default 0 ,
-  event_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  event_time_usec integer default 0 ,
-  scheduled_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  recurring_event integer default 0 ,
-  object_id integer default 0 ,
-  deletion_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  deletion_time_usec integer default 0 
-)tablespace &&DATATBS;
-alter table timedevents add constraint timedevents_pk PRIMARY KEY  (id)
-	using index tablespace &&IDXTBS;
-alter table timedevents add CONSTRAINT timedevents_uq UNIQUE (instance_id,event_type,scheduled_time,object_id)
-	using index tablespace &&IDXTBS;
-
-
 -- --------------------------------------------------------
 
 -- 
@@ -1804,28 +1768,6 @@ alter table timeperiods add CONSTRAINT timeperiods_uq UNIQUE (instance_id,config
 	using index tablespace &&IDXTBS;
 
 
--- --------------------------------------------------------
-
--- 
--- Table structure for table slahistory
--- 
-
-CREATE TABLE slahistory (
-  id integer ,
-  instance_id integer default 0 ,
-  start_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  end_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  acknowledgement_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  object_id integer default 0 ,
-  state integer default 0 ,
-  state_type integer default 0 ,
-  scheduled_downtime integer default 0
-)tablespace &&DATATBS;
-alter table slahistory add constraint slahistory_pk PRIMARY KEY  (id)
-	using index tablespace &&IDXTBS;
-
-
-
 -- -----------------------------------------
 -- add index (delete)
 -- -----------------------------------------
@@ -1837,8 +1779,6 @@ alter table slahistory add constraint slahistory_pk PRIMARY KEY  (id)
 -- EXTERNALCOMMANDS => entry_time
 
 -- instance_id
-CREATE INDEX timedevents_i_id_idx on timedevents(instance_id) tablespace &&IDXTBS;
-CREATE INDEX timedeventq_i_id_idx on timedeventqueue(instance_id) tablespace &&IDXTBS;
 CREATE INDEX systemcommands_i_id_idx on systemcommands(instance_id) tablespace &&IDXTBS;
 CREATE INDEX servicechecks_i_id_idx on servicechecks(instance_id)tablespace &&IDXTBS;
 CREATE INDEX hostchecks_i_id_idx on hostchecks(instance_id) tablespace &&IDXTBS;
@@ -1846,8 +1786,6 @@ CREATE INDEX eventhandlers_i_id_idx on eventhandlers(instance_id) tablespace &&I
 CREATE INDEX externalcommands_i_id_idx on externalcommands(instance_id) tablespace &&IDXTBS;
 
 -- time
-CREATE INDEX timedevents_time_id_idx on timedevents(scheduled_time) tablespace &&IDXTBS;
-CREATE INDEX timedeventq_time_id_idx on timedeventqueue(scheduled_time) tablespace &&IDXTBS;
 CREATE INDEX systemcommands_time_id_idx on systemcommands(start_time) tablespace &&IDXTBS;
 CREATE INDEX servicechecks_time_id_idx on servicechecks(start_time) tablespace &&IDXTBS;
 CREATE INDEX hostchecks_time_id_idx on hostchecks(start_time) tablespace &&IDXTBS;
@@ -1861,7 +1799,6 @@ CREATE INDEX externalcommands_time_id_idx on externalcommands(entry_time) tables
 CREATE INDEX hoststatus_i_id_idx on hoststatus(instance_id) tablespace &&IDXTBS;
 CREATE INDEX servicestatus_i_id_idx on servicestatus(instance_id) tablespace &&IDXTBS;
 CREATE INDEX contactstatus_i_id_idx on contactstatus(instance_id) tablespace &&IDXTBS;
--- CREATE INDEX timedeventqueue_i_id_idx on timedeventqueue(instance_id); -- defined adobe
 CREATE INDEX comments_i_id_idx on comments(instance_id) tablespace &&IDXTBS;
 CREATE INDEX scheduleddowntime_i_id_idx on scheduleddowntime(instance_id) tablespace &&IDXTBS;
 CREATE INDEX runtimevariables_i_id_idx on runtimevariables(instance_id) tablespace &&IDXTBS;
@@ -1945,18 +1882,6 @@ CREATE INDEX srvcstatus_latency_idx on servicestatus(latency) tablespace &&IDXTB
 CREATE INDEX srvcstatus_ex_time_idx on servicestatus(execution_time) tablespace &&IDXTBS;
 CREATE INDEX srvcstatus_sch_downt_d_idx on servicestatus(scheduled_downtime_depth) tablespace &&IDXTBS;
 
--- timedeventqueue
-CREATE INDEX timed_e_q_event_type_idx on timedeventqueue(event_type) tablespace &&IDXTBS;
--- CREATE INDEX timed_e_q_sched_time_idx on timedeventqueue(scheduled_time); -- defined above
-CREATE INDEX timed_e_q_object_id_idx on timedeventqueue(object_id) tablespace &&IDXTBS;
-CREATE INDEX timed_e_q_rec_ev_id_idx on timedeventqueue(recurring_event) tablespace &&IDXTBS;
-
--- timedevents
-CREATE INDEX timed_e_event_type_idx on timedevents(event_type) tablespace &&IDXTBS;
---CREATE INDEX timed_e_sched_time_idx on timedevents(scheduled_time); --already set for delete
-CREATE INDEX timed_e_object_id_idx on timedevents(object_id) tablespace &&IDXTBS;
-CREATE INDEX timed_e_rec_ev_idx on timedevents(recurring_event) tablespace &&IDXTBS;
-
 -- hostchecks
 CREATE INDEX hostchks_h_obj_id_idx on hostchecks(host_object_id) tablespace &&IDXTBS;
 
@@ -1979,10 +1904,6 @@ CREATE INDEX statehist_time_idx on statehistory(instance_id, object_id, state_ty
 create index statehistory_state_idx on statehistory(object_id,state)
 tablespace &&IDXTBS;
 
-
--- slahistory
-CREATE INDEX slahist_idx on slahistory(instance_id,object_id,start_time,end_time) tablespace &&IDXTBS;
-
 -- Icinga Web Notifications
 CREATE INDEX notification_idx ON notifications(notification_type, object_id, start_time) tablespace &&IDXTBS;
 CREATE INDEX notification_object_id_idx ON notifications(object_id) tablespace &&IDXTBS;
@@ -2002,6 +1923,15 @@ CREATE INDEX sgmbrs_sgid_soid ON servicegroup_members (servicegroup_id,service_o
 CREATE INDEX scgrps_sid_cgoid ON service_contactgroups (service_id,contactgroup_object_id) tablespace &&IDXTBS;
 CREATE INDEX tperiod_tid_d_ss_es ON timeperiod_timeranges (timeperiod_id,day,start_sec,end_sec) tablespace &&IDXTBS;
 
+-- #3649
+CREATE INDEX sla_idx_sthist ON statehistory (object_id, state_time DESC) tablespace &&IDXTBS;
+CREATE INDEX sla_idx_dohist ON downtimehistory (object_id, actual_start_time, actual_end_time) tablespace &&IDXTBS;
+CREATE INDEX sla_idx_obj ON objects (objecttype_id, is_active, name1) tablespace &&IDXTBS;
+
+-- #4985
+CREATE INDEX commenthistory_delete_idx ON commenthistory (instance_id, comment_time, internal_comment_id) tablespace &&IDXTBS;
+
+
 -- -----------------------------------------
 -- sequences
 -- -----------------------------------------
@@ -2276,16 +2206,6 @@ CREATE SEQUENCE seq_systemcommands
    increment by 1
    nocache nomaxvalue;
 
-CREATE SEQUENCE seq_timedeventqueue
-   start with 1
-   increment by 1
-   nocache nomaxvalue;
-
-CREATE SEQUENCE seq_timedevents
-   start with 1
-   increment by 1
-   nocache nomaxvalue;
-
 CREATE SEQUENCE seq_timep_timer
    start with 1
    increment by 1
@@ -2358,8 +2278,6 @@ alter sequence SEQ_SERVICE_CONTACTS cache 5;
 alter sequence SEQ_SLAHISTORY cache 20;
 alter sequence SEQ_STATEHISTORY cache 50; 
 alter sequence SEQ_SYSTEMCOMMANDS cache 5; 
-alter sequence SEQ_TIMEDEVENTQUEUE cache 10;
-alter sequence SEQ_TIMEDEVENTS cache 10; 
 alter sequence SEQ_TIMEPERIODS nocache; 
 alter sequence SEQ_TIMEP_TIMER cache 5;
 
